--[[
NAME
    surface_plot
NOTES
    Demonstrates 3D surface plot.
]]

require("read_xml")

arr = read_xml("./examples/lat_ssn_co2.xml")

arr:delete(0)   -- delete the vector containing year
arr:delete(0)   -- delete the vector containing month
arr:flip()      -- make latutide from south to north
arr:transpose() -- time as x and latitude as y

-- Data are too dense with time. Get rid of some.

co2, idx = zeUtl.new("double", "uint")
idx:range(0, 2, 114)
arr:sample(idx, co2)
co2min = co2:min()
co2max = co2:max()

-- Construct the surface

xyz, vec = zeUtl.new("double", "double")

zeMake.grid2quads(xyz, 1, co2)
zeMake.normal4(co2, 10, xyz)

-- CO2 surface and colorbar
shape1, shape2, vertex, normal, color, colorbar
    = zeGrf.new("polygon", "polygon", "vertex", "vertex", "color", "colorbar")
    
shape1:set{vertex = vertex, vertex_normal = normal, vertex_color = color, type = "quads"}
shape2:set{vertex = vertex, type = "quads", fill = 0, smooth = true, color = {0, .5, .5, 1}, linewidth = .1}
shape2:translate(0, 0, .1)
vertex:add(xyz)
normal:add(co2)

colorbar:add{co2min, 0, 0, 1,
            (co2min+co2max)/2, 0, 1, 0,
             co2max, 1, 0, 0}
colorbar:set{interpolation = 3}

n = xyz:size()-1
for k = 0, n do
    r, g, b = colorbar:get(xyz:getele(k, 2))
    color:add(r, g, b)
end

-- setup plot

require("plot_3d")
plot = plot_3d.new(600, 500)
plot:scale(0.6, 0.4, 0.3)
plot:xaxis{range = {0, 113},
           ticklabels = {"83|85|87|89|91|93|95|97|99|01", false},
           tickmarks = {0, 12, 1}, ticklength = 1.5, linewidth = 1.5,
           label = "Year", smooth = true}
plot:yaxis{range = {0, 8},
           ticklabels = {"80S|60S|40S|20S|0|20N|40N|60N|80N", 0},
           tickmarks = {0, 1, 0}, ticklength = 1.5, linewidth = 1.5,
           label = "Latitude", smooth = true}
plot:zaxis{range = {330, 380},
           tickmarks = {340, 10, 1}, ticklength = 1.5, linewidth = 1.5,
           label = "CO2 (ppm)", smooth = true}

-- light effect and smooth blending

light, node = zeGrf.new("light", "node")
light:set{position = {-1, -1, 1}, ambient = {0.7, 0.7 , 0.7, 1}}
plot:add_static(light)
plot:add(shape2)
plot:add(node)
node:add(shape1)    -- put polygon in a closed node to prevent blending
node:set{open = false}

-- Render to window
plot:translate(20, 0, 0)
plot:animate()